==> goods-center-api-1.4-20160621.020110-5-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/GoodsCouponDto.java <==
/**
 * Project Name:goods-center-api
 * File Name:GoodsCouponDTO.java
 * Package Name:cn.com.duiba.goods.center.api.remoteservice.dto
 * Date:2016年5月24日上午9:58:18
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * ClassName:GoodsCouponDTO <br/>
 * Date:     2016年5月24日 上午9:58:18 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class GoodsCouponDto implements Serializable{

    /**
     * @since JDK 1.6
     */
    private static final long serialVersionUID = -4100072591338665695L;

    private Long goodsCouponId;
    
    private Long goodsBatchId;
    
    private Integer gtype;
    
    private Long gid;
    
    private Long batchId;
    
    private String code;
    
    private String password;
    
    private String link;
    
    private Integer status;
    
    private Long consumerId;
    
    private Long orderId;
    
    private Date startDay;
    
    private Date endDay;
    
    private Date gmtCreate;
    
    private Date gmtModified;

    
    public Long getGoodsCouponId() {
        return goodsCouponId;
    }

    
    public void setGoodsCouponId(Long goodsCouponId) {
        this.goodsCouponId = goodsCouponId;
    }

    
    public Long getGoodsBatchId() {
        return goodsBatchId;
    }

    
    public void setGoodsBatchId(Long goodsBatchId) {
        this.goodsBatchId = goodsBatchId;
    }

    
    public Integer getGtype() {
        return gtype;
    }

    
    public void setGtype(Integer gtype) {
        this.gtype = gtype;
    }

    
    public Long getGid() {
        return gid;
    }

    
    public void setGid(Long gid) {
        this.gid = gid;
    }

    
    public Long getBatchId() {
        return batchId;
    }

    
    public void setBatchId(Long batchId) {
        this.batchId = batchId;
    }

    
    public String getCode() {
        return code;
    }

    
    public void setCode(String code) {
        this.code = code;
    }

    
    public String getPassword() {
        return password;
    }

    
    public void setPassword(String password) {
        this.password = password;
    }

    
    public String getLink() {
        return link;
    }

    
    public void setLink(String link) {
        this.link = link;
    }

    
    public Integer getStatus() {
        return status;
    }

    
    public void setStatus(Integer status) {
        this.status = status;
    }

    
    public Long getConsumerId() {
        return consumerId;
    }

    
    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    
    public Long getOrderId() {
        return orderId;
    }

    
    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    
    
    public Date getStartDay() {
		return startDay;
	}


	public void setStartDay(Date startDay) {
		this.startDay = startDay;
	}


	public Date getEndDay() {
		return endDay;
	}


	public void setEndDay(Date endDay) {
		this.endDay = endDay;
	}


	public Date getGmtCreate() {
        return gmtCreate;
    }

    
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    
    public Date getGmtModified() {
        return gmtModified;
    }

    
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> goods-center-api-1.6.3-20160905.040851-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/GoodsCouponDto.java <==
/**
 * Project Name:goods-center-api
 * File Name:GoodsCouponDTO.java
 * Package Name:cn.com.duiba.goods.center.api.remoteservice.dto
 * Date:2016年5月24日上午9:58:18
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * ClassName:GoodsCouponDTO <br/>
 * Date:     2016年5月24日 上午9:58:18 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class GoodsCouponDto implements Serializable{

    /**
     * @since JDK 1.6
     */
    private static final long serialVersionUID = -4100072591338665695L;

    private Long goodsCouponId;
    
    private Long goodsBatchId;
    
    private Integer gtype;
    
    private Long gid;
    
    private Long batchId;
    //过期时间
    private Date overDue;
    
    private String code;
    
    private String password;
    
    private String link;
    
    private Integer status;
    
    private Long consumerId;
    
    private Long orderId;
    
    private Date gmtCreate;
    
    private Date gmtModified;

    
    public Long getGoodsCouponId() {
        return goodsCouponId;
    }

    
    public void setGoodsCouponId(Long goodsCouponId) {
        this.goodsCouponId = goodsCouponId;
    }

    
    public Long getGoodsBatchId() {
        return goodsBatchId;
    }

    
    public void setGoodsBatchId(Long goodsBatchId) {
        this.goodsBatchId = goodsBatchId;
    }

    
    public Integer getGtype() {
        return gtype;
    }

    
    public void setGtype(Integer gtype) {
        this.gtype = gtype;
    }

    
    public Long getGid() {
        return gid;
    }

    
    public void setGid(Long gid) {
        this.gid = gid;
    }

    
    public Long getBatchId() {
        return batchId;
    }

    
    public void setBatchId(Long batchId) {
        this.batchId = batchId;
    }

    
    public String getCode() {
        return code;
    }

    
    public void setCode(String code) {
        this.code = code;
    }

    
    public String getPassword() {
        return password;
    }

    
    public void setPassword(String password) {
        this.password = password;
    }

    
    public String getLink() {
        return link;
    }

    
    public void setLink(String link) {
        this.link = link;
    }

    
    public Integer getStatus() {
        return status;
    }

    
    public void setStatus(Integer status) {
        this.status = status;
    }

    
    public Long getConsumerId() {
        return consumerId;
    }

    
    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    
    public Long getOrderId() {
        return orderId;
    }

    
    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    
    public Date getGmtCreate() {
        return gmtCreate;
    }

    
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    
    public Date getGmtModified() {
        return gmtModified;
    }

    
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }


    
    public Date getOverDue() {
        return overDue;
    }


    
    public void setOverDue(Date overDue) {
        this.overDue = overDue;
    }
}
